<?php
/**
 * Silver Spot functions and definitions, based on ye olde twenty ten
 *
 * silverspot_setup(), sets up the theme by registering support for various features in WordPress,
 * such as post thumbnails, navigation menus, and the like.
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 *
 * Used to set the width of images and content. Should be equal to the width the theme
 * is designed for, generally via the style.css stylesheet.
 */
if ( ! isset( $content_width ) )
	$content_width = 640;

require_once( 'includes/customizer.php' );

add_action( 'after_setup_theme', 'silverspot_setup' );

if ( ! function_exists( 'silverspot_setup' ) ):

function silverspot_setup() {
    
    if(is_admin()) require_once('silverspot_theme_menu.php');
 $themeSettings = get_option( 'silverspot_theme_settings' );

 if( isset($themeSettings['style']) && $themeSettings['style'] == 'burnished' )
 {
 	add_action( 'wp_enqueue_scripts', 'silverspot_burnished_style' );
 	function silverspot_burnished_style()
 	{
 		wp_register_style( 'silverspot-burnished-style', get_stylesheet_directory_uri() . '/css/burnished.css' );
 		wp_enqueue_style( 'silverspot-burnished-style' );
 	}
 }

	add_action( 'customize_register', 'silverspot_customize_register' );
	// This theme styles the visual editor with editor-style.css to match the theme style.
	add_editor_style();

	// Post Format support. You can also use the legacy "gallery" or "asides" (note the plural) categories.
	add_theme_support( 'post-formats', array( 'aside', 'gallery' ) );

	// This theme uses post thumbnails
	add_theme_support( 'post-thumbnails' );
	add_image_size( 'large', 600, 9999 );

	// Add default posts and comments RSS feed links to head
	add_theme_support( 'automatic-feed-links' );

	// Make theme available for translation
	// Translations can be filed in the /languages/ directory
	load_theme_textdomain( 'silverspot', get_template_directory() . '/languages' );

	$locale = get_locale();
	$locale_file = get_template_directory() . "/languages/$locale.php";
	if ( is_readable( $locale_file ) )
		require_once( $locale_file );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => __( 'Primary Navigation', 'silverspot' ),
	) );

	// Allow users to set a custom background
	add_theme_support('custom-background');

	// No CSS, just IMG call. The %s is a placeholder for the theme template directory URI.
	if ( ! defined( 'HEADER_IMAGE' ) )
		define( 'HEADER_IMAGE', '%s/images/headers/silvertop1.jpg' );

	// The height and width of your custom header. You can hook into the theme's own filters to change these values.
	// Add a filter to silverspot_header_image_width and silverspot_header_image_height to change these values.
	define( 'HEADER_IMAGE_WIDTH', apply_filters( 'silverspot_header_image_width', 940 ) );
	define( 'HEADER_IMAGE_HEIGHT', apply_filters( 'silverspot_header_image_height', 198 ) );

	// We'll be using post thumbnails for custom header images on posts and pages.
	// We want them to be 940 pixels wide by 198 pixels tall.
	// Larger images will be auto-cropped to fit, smaller ones will be ignored. See header.php.
	set_post_thumbnail_size( HEADER_IMAGE_WIDTH, HEADER_IMAGE_HEIGHT, true );


	add_theme_support('custom-header', array( 'uploads' => true ));
	
	// Options for theme customization
	if( !get_option( 'silverspot_theme_settings[silverspot_description_colour]' ) )


	// Default custom headers packaged with the theme. %s is a placeholder for the theme template directory URI.
	register_default_headers( array(
		'silvertop1' => array(
			'url' => '%s/images/headers/silvertop1.jpg',
			'thumbnail_url' => '%s/images/headers/silvertop1-thumbnail.jpg',
			'description' => __( 'Silvertop One', 'silverspot' )
		),
		'silvertop2' => array(
			'url' => '%s/images/headers/silvertop2.jpg',
			'thumbnail_url' => '%s/images/headers/silvertop2-thumbnail.jpg',
			'description' => __( 'Silvertop Two', 'silverspot' )
		),
		'silvertop3' => array(
			'url' => '%s/images/headers/silvertop3.jpg',
			'thumbnail_url' => '%s/images/headers/silvertop3-thumbnail.jpg',
			'description' => __( 'Silvertop Three', 'silverspot' )
		),
		'silvertop4' => array(
			'url' => '%s/images/headers/silvertop4.jpg',
			'thumbnail_url' => '%s/images/headers/silvertop4-thumbnail.jpg',
			'description' => __( 'Silvertop Four', 'silverspot' )
		),
		'silvertop5' => array(
			'url' => '%s/images/headers/silvertop5.jpg',
			'thumbnail_url' => '%s/images/headers/silvertop5-thumbnail.jpg',
			'description' => __( 'Silvertop Five', 'silverspot' )
		),
		'silvertop6' => array(
			'url' => '%s/images/headers/silvertop6.jpg',
			'thumbnail_url' => '%s/images/headers/silvertop6-thumbnail.jpg',
			'description' => __( 'Silvertop Six', 'silverspot' )
		),
		'silvertop7' => array(
			'url' => '%s/images/headers/silvertop7.jpg',
			'thumbnail_url' => '%s/images/headers/silvertop7-thumbnail.jpg',
			'description' => __( 'Silvertop Seven', 'silverspot' )
		)
	) );
}
endif;

function silverspot_enqueue_comment_reply() {
	wp_enqueue_script( 'comment-reply' );
}

if ( ! function_exists( 'silverspot_admin_header_style' ) ) :
function silverspot_admin_header_style() {
?>
<style type="text/css">
/* Shows the same border as on front end */
#headimg {
	border-bottom: 1px solid #000;
	border-top: 4px solid #000;
}
</style>
<?php
}
endif;

function silverspot_page_menu_args( $args ) {
	$args['show_home'] = true;
	return $args;
}
add_filter( 'wp_page_menu_args', 'silverspot_page_menu_args' );

function silverspot_excerpt_length( $length ) {
	return 40;
}
add_filter( 'excerpt_length', 'silverspot_excerpt_length' );


function silverspot_continue_reading_link() {
	return ' <a href="'. get_permalink() . '">' . __( 'Continue reading <span class="meta-nav">&rarr;</span>', 'silverspot' ) . '</a>';
}

function silverspot_auto_excerpt_more( $more ) {
	return ' &hellip;' . silverspot_continue_reading_link();
}
add_filter( 'excerpt_more', 'silverspot_auto_excerpt_more' );

/**
 * Adds a pretty "Continue Reading" link to custom post excerpts.
 *
 * To override this link in a child theme, remove the filter and add your own
 * function tied to the get_the_excerpt filter hook.
 */
function silverspot_custom_excerpt_more( $output ) {
	if ( has_excerpt() && ! is_attachment() ) {
		$output .= silverspot_continue_reading_link();
	}
	return $output;
}
add_filter( 'get_the_excerpt', 'silverspot_custom_excerpt_more' );

/**
 * Remove inline styles printed when the gallery shortcode is used.
 *
 * Galleries are styled by the theme in Silver Spot's style.css. This is just
 * a simple filter call that tells WordPress to not use the default styles.
 */
add_filter( 'use_default_gallery_style', '__return_false' );

/**
 * Deprecated way to remove inline styles printed when the gallery shortcode is used.
 *
 * This function is no longer needed or used. Use the use_default_gallery_style
 * filter instead, as seen above.
 *
 * @since Silver Spot 1.0.1
 * @deprecated Deprecated in Silver Spot 1.0.1 for WordPress 3.1
 *
 * @return string The gallery style filter, with the styles themselves removed.
 */
function silverspot_remove_gallery_css( $css ) {
	return preg_replace( "#<style type='text/css'>(.*?)</style>#s", '', $css );
}
// Backwards compatibility with WordPress 3.0.
if ( version_compare( $GLOBALS['wp_version'], '3.1', '<' ) )
	add_filter( 'gallery_style', 'silverspot_remove_gallery_css' );

if ( ! function_exists( 'silverspot_comment' ) ) :
/**
 * Template for comments and pingbacks.
 *
 * To override this walker in a child theme without modifying the comments template
 * simply create your own silverspot_comment(), and that function will be used instead.
 *
 * Used as a callback by wp_list_comments() for displaying the comments.
 *
 * @since Silver Spot 1.0.1
 */
function silverspot_comment( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	switch ( $comment->comment_type ) :
		case '' :
	?>
	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
		<div id="comment-<?php comment_ID(); ?>">
		<div class="comment-author vcard">
			<?php echo get_avatar( $comment, 40 ); ?>
			<?php printf( __( '%s <span class="says">says:</span>', 'silverspot' ), sprintf( '<cite class="fn">%s</cite>', get_comment_author_link() ) ); ?>
		</div><!-- .comment-author .vcard -->
		<?php if ( $comment->comment_approved == '0' ) : ?>
			<em class="comment-awaiting-moderation"><?php _e( 'Your comment is awaiting moderation.', 'silverspot' ); ?></em>
			<br />
		<?php endif; ?>

		<div class="comment-meta commentmetadata"><a href="<?php echo esc_url( get_comment_link( $comment->comment_ID ) ); ?>">
			<?php
				/* translators: 1: date, 2: time */
				printf( __( '%1$s at %2$s', 'silverspot' ), get_comment_date(),  get_comment_time() ); ?></a><?php edit_comment_link( __( '(Edit)', 'silverspot' ), ' ' );
			?>
		</div><!-- .comment-meta .commentmetadata -->

		<div class="comment-body"><?php comment_text(); ?></div>

		<div class="reply">
			<?php comment_reply_link( array_merge( $args, array( 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
		</div><!-- .reply -->
	</div><!-- #comment-##  -->

	<?php
			break;
		case 'pingback'  :
		case 'trackback' :
	?>
	<li class="post pingback">
		<p><?php _e( 'Pingback:', 'silverspot' ); ?> <?php comment_author_link(); ?><?php edit_comment_link( __( '(Edit)', 'silverspot' ), ' ' ); ?></p>
	<?php
			break;
	endswitch;
}
endif;

/**
 * Register widgetized areas, including two sidebars and four widget-ready columns in the footer.
 *
 * To override silverspot_widgets_init() in a child theme, remove the action hook and add your own
 * function tied to the init hook.
 *
 * @since Silver Spot 1.0.1
 * @uses register_sidebar
 */
function silverspot_widgets_init() {
	// Area 1, located at the top of the sidebar.
	register_sidebar( array(
		'name' => __( 'Primary Widget Area', 'silverspot' ),
		'id' => 'primary-widget-area',
		'description' => __( 'The primary widget area', 'silverspot' ),
		'before_widget' => '<li id="%1$s" class="widget-container %2$s">',
		'after_widget' => '</li>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );

	// Area 2, located below the Primary Widget Area in the sidebar. Empty by default.
	register_sidebar( array(
		'name' => __( 'Secondary Widget Area', 'silverspot' ),
		'id' => 'secondary-widget-area',
		'description' => __( 'The secondary widget area', 'silverspot' ),
		'before_widget' => '<li id="%1$s" class="widget-container %2$s">',
		'after_widget' => '</li>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );

	// Area 3, located in the footer. Empty by default.
	register_sidebar( array(
		'name' => __( 'First Footer Widget Area', 'silverspot' ),
		'id' => 'first-footer-widget-area',
		'description' => __( 'The first footer widget area', 'silverspot' ),
		'before_widget' => '<li id="%1$s" class="widget-container %2$s">',
		'after_widget' => '</li>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );

	// Area 4, located in the footer. Empty by default.
	register_sidebar( array(
		'name' => __( 'Second Footer Widget Area', 'silverspot' ),
		'id' => 'second-footer-widget-area',
		'description' => __( 'The second footer widget area', 'silverspot' ),
		'before_widget' => '<li id="%1$s" class="widget-container %2$s">',
		'after_widget' => '</li>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );

	// Area 5, located in the footer. Empty by default.
	register_sidebar( array(
		'name' => __( 'Third Footer Widget Area', 'silverspot' ),
		'id' => 'third-footer-widget-area',
		'description' => __( 'The third footer widget area', 'silverspot' ),
		'before_widget' => '<li id="%1$s" class="widget-container %2$s">',
		'after_widget' => '</li>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );

	// Area 6, located in the footer. Empty by default.
	register_sidebar( array(
		'name' => __( 'Fourth Footer Widget Area', 'silverspot' ),
		'id' => 'fourth-footer-widget-area',
		'description' => __( 'The fourth footer widget area', 'silverspot' ),
		'before_widget' => '<li id="%1$s" class="widget-container %2$s">',
		'after_widget' => '</li>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );

	// Area 7, top right - above the header image
	// register_sidebar( array(
	// 	'name' => __( 'Above Header Widget Area', 'silverspot' ),
	// 	'id' => 'above-header-widget-area',
	// 	'description' => __( 'Top right, above the header image', 'silverspot' ),
	// 	'before_widget' => '<div id="%1$s" class="alignright">',
	// 	'after_widget' => '</div>',
	// 	'before_title' => '<span class="hidden">',
	// 	'after_title' => '</span>',
	// ) );

	// Area 8, located in the footer. Empty by default.
	register_sidebar( array(
		'name' => __( 'Primary Left Widget Area', 'silverspot' ),
		'id' => 'left-primary-widget-area',
		'description' => __( 'First widget in the left column', 'silverspot' ),
		'before_widget' => '<li id="%1$s" class="widget-container %2$s">',
		'after_widget' => '</li>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );

	// Area 9, located in the footer. Empty by default.
	register_sidebar( array(
		'name' => __( 'Secondary Left Widget Area', 'silverspot' ),
		'id' => 'left-secondary-widget-area',
		'description' => __( 'Second widget in the left column', 'silverspot' ),
		'before_widget' => '<li id="%1$s" class="widget-container %2$s">',
		'after_widget' => '</li>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );
}
/** Register sidebars by running silverspot_widgets_init() on the widgets_init hook. */
add_action( 'widgets_init', 'silverspot_widgets_init' );

/**
 * Removes the default styles that are packaged with the Recent Comments widget.
 *
 * To override this in a child theme, remove the filter and optionally add your own
 * function tied to the widgets_init action hook.
 *
 * This function uses a filter (show_recent_comments_widget_style) new in WordPress 3.1
 * to remove the default style. Using Silver Spot 1.0.1 in WordPress 3.0 will show the styles,
 * but they won't have any effect on the widget in default Silver Spot styling.
 *
 * @since Silver Spot 1.0.1
 */
function silverspot_remove_recent_comments_style() {
	add_filter( 'show_recent_comments_widget_style', '__return_false' );
}
add_action( 'widgets_init', 'silverspot_remove_recent_comments_style' );

if ( ! function_exists( 'silverspot_posted_on' ) ) :
/**
 * Prints HTML with meta information for the current post-date/time and author.
 *
 * @since Silver Spot 1.0.1
 */
function silverspot_posted_on() {
	printf( __( '<span class="%1$s">Posted on</span> %2$s <span class="meta-sep">by</span> %3$s', 'silverspot' ),
		'meta-prep meta-prep-author',
		sprintf( '<a href="%1$s" title="%2$s" rel="bookmark"><span class="entry-date">%3$s</span></a>',
			get_permalink(),
			esc_attr( get_the_time() ),
			get_the_date()
		),
		sprintf( '<span class="author vcard"><a class="url fn n" href="%1$s" title="%2$s">%3$s</a></span>',
			get_author_posts_url( get_the_author_meta( 'ID' ) ),
			sprintf( esc_attr__( 'View all posts by %s', 'silverspot' ), get_the_author() ),
			get_the_author()
		)
	);
}
endif;

if ( ! function_exists( 'silverspot_posted_in' ) ) :
/**
 * Prints HTML with meta information for the current post (category, tags and permalink).
 *
 * @since Silver Spot 1.0.1
 */
function silverspot_posted_in() {
	// Retrieves tag list of current post, separated by commas.
	$tag_list = get_the_tag_list( '', ', ' );
	if ( $tag_list ) {
		$posted_in = __( 'This entry was posted in %1$s and tagged %2$s. Bookmark the <a href="%3$s" title="Permalink to %4$s" rel="bookmark">permalink</a>.', 'silverspot' );
	} elseif ( is_object_in_taxonomy( get_post_type(), 'category' ) ) {
		$posted_in = __( 'This entry was posted in %1$s. Bookmark the <a href="%3$s" title="Permalink to %4$s" rel="bookmark">permalink</a>.', 'silverspot' );
	} else {
		$posted_in = __( 'Bookmark the <a href="%3$s" title="Permalink to %4$s" rel="bookmark">permalink</a>.', 'silverspot' );
	}
	// Prints the string, replacing the placeholders.
	printf(
		$posted_in,
		get_the_category_list( ', ' ),
		$tag_list,
		get_permalink(),
		the_title_attribute( 'echo=0' )
	);
}
endif;

if ( ! function_exists( 'silverspot_title_filter' ) ) :
	function silverspot_title_filter( $title, $sep ) {
		global $paged, $page, $pagename;

		if ( is_feed() )
			return $title;

		if( is_front_page() )
			return $title . get_bloginfo( 'name' );

		// Add a page number if necessary.
		if ( $paged >= 2 || $page >= 2 )
			$title = "$title $sep " . sprintf( __( 'Page %s', 'silverspot' ), max( $paged, $page ) );
		return $title;
	}
endif;

add_filter( 'wp_title', 'silverspot_title_filter', 1, 2 );


function silverspot_isHexCol( $str )
{
	if( preg_match('/^([A-Fa-f0-9]{3}){1,2}$/', $str ) )
		return $str;
	return '';
}