<?php

function silverspot_customize_register( $wp_customize )
{
	// Header text colors
	$wp_customize->add_setting( 'silverspot_theme_settings[silverspot_description_colour]', array(
		'default'					=> 'FFF',
		'type' 						=> 'option',
		'sanitize_callback'		=> 'silverspot_sanitize_color',
		'sanitize_js_callback'	=> 'maybe_hash_hex_color'
	) );

	$wp_customize->add_control(  new WP_Customize_Color_Control( $wp_customize, 'silverspot_theme_settings[silverspot_description_colour]',
		array(
			'label'		=> __( 'Site Tagline Color', 'silverspot' ),
			'section'	=> 'colors',
			'settings'	=> 'silverspot_theme_settings[silverspot_description_colour]'
			)
	));

	// Display or hide top search box
	$wp_customize->add_setting( 'silverspot_theme_settings[hide-search]', array(
		'default'		=> 0,
		'type' 			=> 'option',
		'transport'		=> 'postMessage'
	) );

	$wp_customize->add_control(  'silverspot_theme_settings[hide-search]', array(
			'label'		=> __( 'Hide Header Search', 'silverspot' ),
			'type'		=> 'checkbox',
			'section'	=> 'silverspot_custom_post_layout',
			'settings'	=> 'silverspot_theme_settings[hide-search]'
			)
	);

	// Add three columns to blog index and posts
	$wp_customize->add_section( 'silverspot_custom_post_layout' , array(
		'title'      	=> __('Silver Spot Custom Options','silverspot'),
		'priority'   	=> 40,
	) );

	$wp_customize->add_setting( 'silverspot_theme_settings[colspost-index]', array(
		'default'		=> '2',
		'type' 			=> 'option'
	) );
	
	$wp_customize->add_setting( 'silverspot_theme_settings[colspost-post]', array(
		'default'		=> '2',
		'type' 			=> 'option'
	) );
	
	$wp_customize->add_setting( 'silverspot_theme_settings[style]', array(
		'default'		=> 'electric',
		'type' 			=> 'option'
	) );

	$wp_customize->add_control(  'silverspot_theme_settings[colspost-index]', array(
		'label'		=> __('Columns on Blog Index', 'silverspot' ),
		'section'	=> 'silverspot_custom_post_layout',
		'type'		=> 'radio',
		'choices'	=> array(
			'2' => '2 Columns',
			'3' => '3 Columns'
			)
	) );

	$wp_customize->add_control(  'silverspot_theme_settings[colspost-post]', array(
		'label'		=> __('Columns on Posts', 'silverspot' ),
		'section'	=> 'silverspot_custom_post_layout',
		'type'		=> 'radio',
		'choices'	=> array(
			'2' => '2 Columns',
			'3' => '3 Columns'
			)
	) );

	$wp_customize->add_control(  'silverspot_theme_settings[style]', array(
		'label'		=> __('Style', 'silverspot' ),
		'section'	=> 'silverspot_custom_post_layout',
		'type'		=> 'radio',
		'choices'	=> array(
			'electric' => 'Electric Silver',
			'burnished' => 'Burnished Silver'
			)
	) );

	// Hook to ajax update
	$wp_customize->get_setting('header_textcolor')->transport='postMessage';
	$wp_customize->get_setting('blogname')->transport='postMessage';
	$wp_customize->get_setting('blogdescription')->transport='postMessage';

	if ( $wp_customize->is_preview() && ! is_admin() )
		add_action( 'wp_footer', 'silverspot_customize_preview', 21);

}

function silverspot_customize_preview() {
	?>
	<script type="text/javascript">
		( function( $ ) {
			wp.customize('header_textcolor',function( value ) {
				value.bind (function( to ) {
					if( 'blank' == to )
					{
						$('.site-title').hide();
						$('#site-description').hide();
					}
					else
					{
						$('.site-title').show();
						$('#site-description').show();
						$('.site-title').find('a').css('color', to ? to : '' );
					}
				});
			});
			wp.customize('blogname',function( value ) {
				value.bind (function( to ) {
					$('.site-title').find('a').text(to);
				});
			});
			wp.customize('blogdescription',function( value ) {
				value.bind (function( to ) {
					$('#site-description').text(to);
				});
			});
			wp.customize('silverspot_theme_settings[hide-search]',function( value ) {
				value.bind (function( to ) {
					if( to ) $('#topwidget').hide();
					else $('#topwidget').show();
				});
			});
		} )( jQuery )
	</script>
	<?php 
} 

function silverspot_sanitize_color( $color ) {
	return ( 'blank' === $color ) ? 'blank' : sanitize_hex_color_no_hash( $color );
}