<?php

/** Trigger theme menu at admin_menu hook **/
add_action('admin_menu', 'silverspot_theme_menu');
add_action('admin_init', 'silverspot_register_settings');

if( ! function_exists( 'silverspot_theme_menu' ) ) :

function silverspot_theme_menu() {
    add_theme_page(
    	'Silver Spot ' . __('Customization Options', 'silverspot' ), 'Silver Spot ' . __('Options', 'silverspot'), 'read', 'silverspot-theme-options', 'silverspot_theme_options' );
}
endif;

if( ! function_exists( 'silverspot_theme_options' ) ) :

function silverspot_theme_options() {
    // Check that the user is allowed to update options  
    if (!current_user_can('manage_options')) wp_die('You do not have sufficient permissions to access this page.'); 
    ?>
    <div class="wrap">
    	<?php screen_icon('themes'); ?> <h2>Silver Spot <?php echo __('Theme Settings', 'silverspot' ); ?></h2>
        <div class="postbox" style="padding: 10px;margin-top:20px">
            <b>Note:</b> 
        <?php
        $wpVer = 0 + implode( '', array_slice( explode( '.', get_bloginfo('version') ), 0, 2 ));
        // Check if customize interface is there
        if( version_compare( $GLOBALS['wp_version'], '3.4', '>=' ) ) {
            ?>Many options for this theme are now configurable through the <a href="customize.php">theme customizer interface</a>. We suggest that you use that instead.
        <?php
        }
        else echo 'We recommend upgrading your WordPress install to the latest version, to get the most from this theme.'
        ?>
        </div>
        <form method="POST" action="options.php">
        <?php
        settings_fields('silverspot_theme_settings');
        $settings = get_option('silverspot_theme_settings');
        ?>
            <table class="form-table">  
            <tr valign="top">  
            	<th scope="row">
                    	Theme style:
                </th>  
                <td>
						<label for="electricStyle">
							<input type="radio" name="silverspot_theme_settings[style]" id="electricStyle" value="electric"<?php if( $settings['style'] == 'electric' ) echo ' checked="checked"';?>> Electric Silver</label><br>
						<label for="burnishedStyle">
							<input type="radio" name="silverspot_theme_settings[style]" id="burnishedStyle" value="burnished"<?php if( $settings['style'] == 'burnished' ) echo ' checked="checked"';?>> Burnished Silver</label>
                </td>  
            </tr>
            <tr valign="top">  
            	<th scope="row">  
                    <label for="silverspot_title_colour">  
                    	Site title text colour:
                    </label>  
                </th>  
                <td>  
                	# <input type="text" name="silverspot_theme_settings[silverspot_title_colour]" value="<?php echo get_header_textcolor(); ?>" size="6" />  
                </td>  
            </tr>  
            <tr valign="top">  
            	<th scope="row">  
                    <label for="silverspot_description_colour">  
                    	Site description text colour:
                    </label>  
                </th>  
                <td>  
                	# <input type="text" id="silverspot_description_colour" name="silverspot_theme_settings[silverspot_description_colour]" value="<?php echo $settings['silverspot_description_colour']; ?>" size="6" /> 
                </td>  
            </tr>  
            <tr valign="top">  
            	<th scope="row">
                    	Posts index page layout:
                </th>  
                <td>
						<label for="postsIndex2col">
							<input type="radio" name="silverspot_theme_settings[colspost-index]" id="postsIndex2col" value="2"<?php if( $settings['colspost-index'] == '2' ) echo ' checked="checked"';?>> 2 columns</label><br>
						<label for="postsIndex3col">
							<input type="radio" name="silverspot_theme_settings[colspost-index]" id="postsIndex3col"value="3"<?php if( $settings['colspost-index'] == '3' ) echo ' checked="checked"';?>> 3 columns</label>
                </td>  
            </tr>  
            <tr valign="top">  
            	<th scope="row">
                    	Posts layout:
                </th>  
                <td>
						<label for="postsColsLayout2">
							<input type="radio" name="silverspot_theme_settings[colspost-post]" id="postsColsLayout2" value="2"<?php if( $settings['colspost-post'] == '2' ) echo ' checked="checked"';?>> 2 columns</label><br>
						<label for="postsColsLayout3">
							<input type="radio" name="silverspot_theme_settings[colspost-post]" id="postsColsLayout3" value="3"<?php if( $settings['colspost-post'] == '3' ) echo ' checked="checked"';?>> 3 columns</label>
                </td>  
            </tr>
            <tr valign="top">  
            	<th scope="row">
               	Hide Top Search:
                </th>  
                <td>
						<label for="hideTopSearch">
							<input type="checkbox" name="silverspot_theme_settings[hide-search]" id="hideTopSearch"<?php
								if( $settings['hide-search'] == 'on' ) echo ' checked="checked"';
							?>>
						</label>
                </td>  
            </tr>
            </table>
            <p class="submit">
            <input type="submit" name="save-background-options" id="save-background-options" class="button-primary" value="Save Changes"></p>
        </form>  
    </div>
<?php
}
endif;

/**
 * Register theme options
 */
function silverspot_register_settings() {
    // Serialise the settings
    register_setting( 'silverspot_theme_settings', 'silverspot_theme_settings', 'silverspot_option_validate' );
    $settings = get_option('silverspot_theme_settings' );
    if( empty($settings['silverspot_description_colour'] ) )
    {
        $settings['silverspot_description_colour'] = 'fff';
        update_option( 'silverspot_theme_settings', $settings );
    }
    // 2 or 3 columns for posts pages
    if( empty($settings['colspost-index'] ) )
    {
        $settings['colspost-index'] = '2';
        update_option( 'silverspot_theme_settings', $settings );
    }
    if( empty($settings['colspost-post'] ) )
    {
        $settings['colspost-post'] = '2';
        update_option( 'silverspot_theme_settings', $settings );
    }
    if( empty($settings['style'] ) )
    {
        $settings['style'] = 'electric';
        update_option( 'silverspot_theme_settings', $settings );
    }
    if( empty($settings['hide-search'] ) )
    {
        $settings['hide-search'] = 'off';
        update_option( 'silverspot_theme_settings', $settings );
    }
}

/**
 * Validate theme options
 */
function silverspot_option_validate( $input ) {
	
	$validated = array();

	if( isset( $input['silverspot_description_colour'] ) )
	{
		$validated['silverspot_description_colour'] = silverspot_isHexCol( $input['silverspot_description_colour'] );
	}

	if( isset( $input['silverspot_title_colour'] ) )
		$validated['silverspot_title_colour'] = silverspot_isHexCol( $input['silverspot_title_colour'] );

	if( isset($validated['silverspot_title_colour']) && isset($validated['silverspot_title_colour'] ) )
	{
		$wto = get_option( 'theme_mods_silverspot' );
		$wto['header_textcolor'] = $validated['silverspot_title_colour'];
		update_option( 'theme_mods_silverspot', $wto );
	}

	if( isset($input['colspost-index']) && ($cpi = $input['colspost-index']) )
		if( $cpi == '2' || $cpi == '3' ) $validated['colspost-index'] = $cpi;

	if( isset($input['colspost-post']) && ($cpp = $input['colspost-post']) )
		if( $cpp == '2' || $cpp == '3' ) $validated['colspost-post'] = $cpp;

	if( isset($input['hide-search']) ) $validated['hide-search'] = $input['hide-search'];

	if( isset( $input['style'] ) )
	{
		if( in_array( $input['style'], array( 'electric', 'burnished' ) ))
				$validated['style'] = $input['style'];
	}

	return $validated;
}